==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/awscdk/CdkTasks.java <==
package io.github.cdklabs.projen.awscdk;

/**
 * (experimental) Adds standard AWS CDK tasks to your project.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.568Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.awscdk.CdkTasks")
public class CdkTasks extends io.github.cdklabs.projen.Component {

    protected CdkTasks(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CdkTasks(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public CdkTasks(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) Deploys your app.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getDeploy() {
        return software.amazon.jsii.Kernel.get(this, "deploy", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) Destroys all the stacks.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getDestroy() {
        return software.amazon.jsii.Kernel.get(this, "destroy", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) Diff against production.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getDiff() {
        return software.amazon.jsii.Kernel.get(this, "diff", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) Synthesizes your app.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getSynth() {
        return software.amazon.jsii.Kernel.get(this, "synth", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) Watch task.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getWatch() {
        return software.amazon.jsii.Kernel.get(this, "watch", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/awscdk/CdkTasks.java <==
package io.github.cdklabs.projen.awscdk;

/**
 * (experimental) Adds standard AWS CDK tasks to your project.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.261Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.awscdk.CdkTasks")
public class CdkTasks extends io.github.cdklabs.projen.Component {

    protected CdkTasks(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CdkTasks(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public CdkTasks(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) Deploys your app.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getDeploy() {
        return software.amazon.jsii.Kernel.get(this, "deploy", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) Destroys all the stacks.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getDestroy() {
        return software.amazon.jsii.Kernel.get(this, "destroy", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) Diff against production.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getDiff() {
        return software.amazon.jsii.Kernel.get(this, "diff", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) Synthesizes your app.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getSynth() {
        return software.amazon.jsii.Kernel.get(this, "synth", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) Synthesizes your app and suppresses stdout.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getSynthSilent() {
        return software.amazon.jsii.Kernel.get(this, "synthSilent", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) Watch task.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getWatch() {
        return software.amazon.jsii.Kernel.get(this, "watch", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }
}
